dynamodb_execute_scan

Function dynamodb_execute_scan 

pub async fn dynamodb_execute_scan<TD: TableDefinition>(
    builder: ScanFluentBuilder,
) -> Result<Vec<Item<TD>>>
Executes a DynamoDB Scan request, collecting all pages into a Vec.

Automatically follows LastEvaluatedKey pagination tokens until all items have been retrieved. This is the low-level function used by ScanRequest::all. Prefer using DynamoDBItemOp::scan or ScanRequest directly unless you are working with a raw ScanFluentBuilder.

Errors

Returns Err if any DynamoDB page request fails.

Examples

use dynamodb_facade::dynamodb_execute_scan;

let builder = client.scan().table_name("platform");
let items = dynamodb_execute_scan::<PlatformTable>(builder).await?;