pub struct UpdateSetRhs<'a>(/* private fields */);Expand description
Advanced right-hand-side expression builder for DynamoDB SET actions.
UpdateSetRhs<'a> represents the right-hand side of a SET attr = <rhs>
expression. It is used with Update::set_custom when the simple
Update::set shorthand is insufficient — for example, when you need to
reference another attribute, use if_not_exists, or build complex
arithmetic expressions.
UpdateSetRhs values can be combined with + and - to ease building
of arithmetic expressions:
use dynamodb_facade::{Update, UpdateSetRhs};
// SET score = other_score + 10
let rhs = UpdateSetRhs::attr("other_score") + UpdateSetRhs::value(10);
let update = Update::set_custom("score", rhs);
assert_eq!(format!("{update}"), r#"SET score = other_score + N("10")"#);
// SET balance = base_balance - penalty
let rhs = UpdateSetRhs::attr("base_balance") - UpdateSetRhs::attr("penalty");
let update = Update::set_custom("balance", rhs);
assert_eq!(format!("{update}"), "SET balance = base_balance - penalty");Implementations
Sourceimpl<'a> UpdateSetRhs<'a>
impl<'a> UpdateSetRhs<'a>
Sourcepub fn value(value: impl IntoAttributeValue) -> Self
pub fn value(value: impl IntoAttributeValue) -> Self
Creates an RHS that reference a literal value.
This is the simplest form. For most cases, Update::set is more
ergonomic and equivalent.
Examples
use dynamodb_facade::{Update, UpdateSetRhs};
let update = Update::set_custom("score", UpdateSetRhs::value(100));
assert_eq!(format!("{update}"), r#"SET score = N("100")"#);
// Same as Update::set
let update = Update::set("score", 100);
assert_eq!(format!("{update}"), r#"SET score = N("100")"#);Sourcepub fn attr(attr: impl Into<Cow<'a, str>>) -> Self
pub fn attr(attr: impl Into<Cow<'a, str>>) -> Self
Creates an RHS that references another attribute by name.
Use this to copy one attribute’s value to another, or as part of an arithmetic expression.
Examples
use dynamodb_facade::{Update, UpdateSetRhs};
// SET old_score = current_score
let update = Update::set_custom("old_score", UpdateSetRhs::attr("current_score"));
assert_eq!(format!("{update}"), "SET old_score = current_score");Sourcepub fn if_not_exists(
attr: impl Into<Cow<'a, str>>,
value: impl IntoAttributeValue,
) -> Self
pub fn if_not_exists( attr: impl Into<Cow<'a, str>>, value: impl IntoAttributeValue, ) -> Self
Creates an RHS using if_not_exists(attr, default).
Evaluates to the current value of attr if it exists, or default
otherwise. Useful for initializing an attribute on first write without
overwriting an existing value.
Examples
use dynamodb_facade::{Update, UpdateSetRhs};
// SET old_score = if_not_exists(score, 0)
let update = Update::set_custom(
"old_score",
UpdateSetRhs::if_not_exists("score", 0),
);
assert_eq!(
format!("{update}"),
r#"SET old_score = if_not_exists(score, N("0"))"#
);Trait Implementations
Sourceimpl<'a> Add for UpdateSetRhs<'a>
Combines two RHS expressions with addition: expr1 + expr2.
impl<'a> Add for UpdateSetRhs<'a>
Combines two RHS expressions with addition: expr1 + expr2.
Produces a expr1 + expr2 arithmetic expression fragment for use in a SET
action.
Examples
use dynamodb_facade::{Update, UpdateSetRhs};
// SET score = base_score + 10
let update = Update::set_custom(
"score",
UpdateSetRhs::attr("base_score") + UpdateSetRhs::value(10),
);
assert_eq!(format!("{update}"), r#"SET score = base_score + N("10")"#);
// SET balance = base_balance + last_payment
let rhs = UpdateSetRhs::attr("base_balance") + UpdateSetRhs::attr("last_payment");
let update = Update::set_custom("balance", rhs);
assert_eq!(format!("{update}"), "SET balance = base_balance + last_payment");Sourcetype Output = UpdateSetRhs<'a>
type Output = UpdateSetRhs<'a>
+ operator.Sourceimpl<'a> Clone for UpdateSetRhs<'a>
impl<'a> Clone for UpdateSetRhs<'a>
Sourcefn clone(&self) -> UpdateSetRhs<'a>
fn clone(&self) -> UpdateSetRhs<'a>
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<'a> Debug for UpdateSetRhs<'a>
impl<'a> Debug for UpdateSetRhs<'a>
Sourceimpl<'a> Sub for UpdateSetRhs<'a>
Combines two RHS expressions with subtraction: expr1 - expr2.
impl<'a> Sub for UpdateSetRhs<'a>
Combines two RHS expressions with subtraction: expr1 - expr2.
Produces a expr1 - expr2 arithmetic expression fragment for use in a SET
action.
Examples
use dynamodb_facade::{Update, UpdateSetRhs};
// SET balance = base_balance - 5
let update = Update::set_custom(
"balance",
UpdateSetRhs::attr("base_balance") - UpdateSetRhs::value(5),
);
assert_eq!(format!("{update}"), r#"SET balance = base_balance - N("5")"#);
// SET balance = base_balance - penalty
let rhs = UpdateSetRhs::attr("base_balance") - UpdateSetRhs::attr("penalty");
let update = Update::set_custom("balance", rhs);
assert_eq!(format!("{update}"), "SET balance = base_balance - penalty");Sourcetype Output = UpdateSetRhs<'a>
type Output = UpdateSetRhs<'a>
- operator.Auto Trait Implementations
impl<'a> Freeze for UpdateSetRhs<'a>
impl<'a> RefUnwindSafe for UpdateSetRhs<'a>
impl<'a> Send for UpdateSetRhs<'a>
impl<'a> Sync for UpdateSetRhs<'a>
impl<'a> Unpin for UpdateSetRhs<'a>
impl<'a> UnsafeUnpin for UpdateSetRhs<'a>
impl<'a> UnwindSafe for UpdateSetRhs<'a>