pub struct Enrollment {
pub user_id: String,
pub course_id: String,
pub enrolled_at: u64,
pub progress: f64,
}Expand description
A user’s enrollment in a course.
Stored at PK = "USER#<user_id>", SK = "ENROLL#<course_id>".
Accessed via Enrollment::get(client, KeyId::pk(user_id).sk(course_id)).
Fields
user_id: Stringcourse_id: Stringenrolled_at: u64progress: f64Trait Implementations
Sourceimpl Clone for Enrollment
impl Clone for Enrollment
Sourcefn clone(&self) -> Enrollment
fn clone(&self) -> Enrollment
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Enrollment
impl Debug for Enrollment
Sourceimpl<'de> Deserialize<'de> for Enrollment
impl<'de> Deserialize<'de> for Enrollment
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DynamoDBItem<PlatformTable> for Enrollment
impl DynamoDBItem<PlatformTable> for Enrollment
Sourceimpl HasAttribute<PK> for Enrollment
impl HasAttribute<PK> for Enrollment
Sourcetype Value = String
type Value = String
A Rust type convertible to the DynamoDB attribute value for this
attribute. Read more
Sourcefn attribute_id(&self) -> Self::Id<'_>
fn attribute_id(&self) -> Self::Id<'_>
Extracts the attribute ID from this item.
Sourcefn attribute_value(id: Self::Id<'_>) -> Self::Value
fn attribute_value(id: Self::Id<'_>) -> Self::Value
Converts an attribute ID into a Rust value of type
Self::Value
which can then be converted into the correct AttributeValue
at serialization using the via
IntoTypedAttributeValue.Sourcefn attribute(&self) -> Self::Value
fn attribute(&self) -> Self::Value
Convenience method: calls
attribute_id
then attribute_value, returning a
Rust value of type Self::Value.Sourceimpl HasAttribute<SK> for Enrollment
impl HasAttribute<SK> for Enrollment
Sourcetype Value = String
type Value = String
A Rust type convertible to the DynamoDB attribute value for this
attribute. Read more
Sourcefn attribute_id(&self) -> Self::Id<'_>
fn attribute_id(&self) -> Self::Id<'_>
Extracts the attribute ID from this item.
Sourcefn attribute_value(id: Self::Id<'_>) -> Self::Value
fn attribute_value(id: Self::Id<'_>) -> Self::Value
Converts an attribute ID into a Rust value of type
Self::Value
which can then be converted into the correct AttributeValue
at serialization using the via
IntoTypedAttributeValue.Sourcefn attribute(&self) -> Self::Value
fn attribute(&self) -> Self::Value
Convenience method: calls
attribute_id
then attribute_value, returning a
Rust value of type Self::Value.Sourceimpl HasConstAttribute<ItemType> for Enrollment
impl HasConstAttribute<ItemType> for Enrollment