pub struct User {
pub id: String,
pub name: String,
pub email: String,
pub role: String,
}Expand description
A registered user on the platform.
Stored at PK = "USER#<id>", SK = "USER".
Accessed via User::get(client, KeyId::pk(user_id)).
Fields
id: Stringname: Stringemail: Stringrole: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for User
impl<'de> Deserialize<'de> for User
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DynamoDBItem<PlatformTable> for User
impl DynamoDBItem<PlatformTable> for User
Sourceimpl HasAttribute<Email> for User
impl HasAttribute<Email> for User
Sourcetype Value = String
type Value = String
A Rust type convertible to the DynamoDB attribute value for this
attribute. Read more
Sourcefn attribute_id(&self) -> Self::Id<'_>
fn attribute_id(&self) -> Self::Id<'_>
Extracts the attribute ID from this item.
Sourcefn attribute_value(id: Self::Id<'_>) -> Self::Value
fn attribute_value(id: Self::Id<'_>) -> Self::Value
Converts an attribute ID into a Rust value of type
Self::Value
which can then be converted into the correct AttributeValue
at serialization using the via
IntoTypedAttributeValue.Sourcefn attribute(&self) -> Self::Value
fn attribute(&self) -> Self::Value
Convenience method: calls
attribute_id
then attribute_value, returning a
Rust value of type Self::Value.Sourceimpl HasAttribute<PK> for User
impl HasAttribute<PK> for User
Sourcetype Value = String
type Value = String
A Rust type convertible to the DynamoDB attribute value for this
attribute. Read more
Sourcefn attribute_id(&self) -> Self::Id<'_>
fn attribute_id(&self) -> Self::Id<'_>
Extracts the attribute ID from this item.
Sourcefn attribute_value(id: Self::Id<'_>) -> Self::Value
fn attribute_value(id: Self::Id<'_>) -> Self::Value
Converts an attribute ID into a Rust value of type
Self::Value
which can then be converted into the correct AttributeValue
at serialization using the via
IntoTypedAttributeValue.Sourcefn attribute(&self) -> Self::Value
fn attribute(&self) -> Self::Value
Convenience method: calls
attribute_id
then attribute_value, returning a
Rust value of type Self::Value.Sourceimpl HasConstAttribute<ItemType> for User
impl HasConstAttribute<ItemType> for User
Sourceimpl HasConstAttribute<SK> for User
impl HasConstAttribute<SK> for User