pub trait KeySchemaKind: KeySchemaKindSeal { }Expand description
Sealed marker trait for key schema kinds.
Implemented only by SimpleKey and CompositeKey. This trait is
sealed and cannot be implemented outside of this crate. It is used as a
bound on KeySchema::Kind to restrict the set of valid key schema
configurations.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".